==> danger_core-1.0.0.tar.gz: lib/src/models/gitlab_dsl.dart <==
import 'package:danger_core/src/mock_json_annotation.dart';

part 'gitlab_dsl.g.dart';

class GitLabDSL {
  final GitLabMergeRequest mergeRequest;

  final GitLabMetadata metadata;

  GitLabDSL({required this.mergeRequest, required this.metadata});

  factory GitLabDSL.fromJson(Map<String, dynamic> json) =>
      _$GitLabDSLFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabDSLToJson(this);
}

class GitLabDiffRefs {
  final String baseSha;

  final String headSha;

  final String startSha;

  GitLabDiffRefs(
      {required this.baseSha, required this.headSha, required this.startSha});

  factory GitLabDiffRefs.fromJson(Map<String, dynamic> json) =>
      _$GitLabDiffRefsFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabDiffRefsToJson(this);
}

class GitLabUserMergeData {
  final bool canMerge;

  GitLabUserMergeData({required this.canMerge});

  factory GitLabUserMergeData.fromJson(Map<String, dynamic> json) =>
      _$GitLabUserMergeDataFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabUserMergeDataToJson(this);
}

class GitLabMergeRequest {
  final bool allowCollaboration;

  final bool allowMaintainerToPush;

  final int? approvalsBeforeMerge;

  final GitLabUser? assignee;

  final GitLabUser author;

  final String changesCount;

  final DateTime? closedAt;

  final GitLabUser? closedBy;

  final String description;

  final GitLabDiffRefs diffRefs;

  final int downvotes;

  final DateTime? firstDeployedToProductionAt;

  final bool forceRemoveSourceBranch;

  final int id;

  final int iid;

  final DateTime? latestBuildFinishedAt;

  final DateTime? latestBuildStartedAt;

  final List<String> labels;

  final String? mergeCommitSha;

  final DateTime? mergedAt;

  final GitLabUser? mergedBy;

  final bool mergeOnPipelineSuccess;

  final GitLabMilestone? milestone;

  final GitLabPipeline pipeline;

  final int projectId;

  final String sha;

  final bool? shouldRemoveSourceBranch;

  final String sourceBranch;

  final int sourceProjectId;

  final GitLabMergeRequestState state;

  final bool subscribed;

  final String targetBranch;

  final int targetProjectId;

  final GitLabMergeRequestTimeStats? timeStats;

  final String title;

  final int upvotes;

  final GitLabUserMergeData userMergeData;

  final int userNotesCount;

  final String webUrl;

  final bool workInProgress;

  GitLabMergeRequest(
      {required this.allowCollaboration,
      required this.allowMaintainerToPush,
      this.approvalsBeforeMerge,
      this.assignee,
      required this.author,
      required this.changesCount,
      this.closedAt,
      this.closedBy,
      required this.description,
      required this.diffRefs,
      required this.downvotes,
      this.firstDeployedToProductionAt,
      required this.forceRemoveSourceBranch,
      required this.id,
      required this.iid,
      this.latestBuildFinishedAt,
      this.latestBuildStartedAt,
      required this.labels,
      this.mergeCommitSha,
      this.mergedAt,
      this.mergedBy,
      required this.mergeOnPipelineSuccess,
      this.milestone,
      required this.pipeline,
      required this.projectId,
      required this.sha,
      this.shouldRemoveSourceBranch,
      required this.sourceBranch,
      required this.sourceProjectId,
      required this.state,
      required this.subscribed,
      required this.targetBranch,
      required this.targetProjectId,
      this.timeStats,
      required this.title,
      required this.upvotes,
      required this.userMergeData,
      required this.userNotesCount,
      required this.webUrl,
      required this.workInProgress});

  factory GitLabMergeRequest.fromJson(Map<String, dynamic> json) =>
      _$GitLabMergeRequestFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMergeRequestToJson(this);
}

class GitLabMergeRequestTimeStats {
  final int humanTimeEstimate;

  final int humanTimeSpent;

  final int timeEstimate;

  final int totalTimeSpent;

  GitLabMergeRequestTimeStats(
      {required this.humanTimeEstimate,
      required this.humanTimeSpent,
      required this.timeEstimate,
      required this.totalTimeSpent});

  factory GitLabMergeRequestTimeStats.fromJson(Map<String, dynamic> json) =>
      _$GitLabMergeRequestTimeStatsFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMergeRequestTimeStatsToJson(this);
}

class GitLabMetadata {
  final String pullRequestID;
  final String repoSlug;

  GitLabMetadata({required this.pullRequestID, required this.repoSlug});

  factory GitLabMetadata.fromJson(Map<String, dynamic> json) =>
      _$GitLabMetadataFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMetadataToJson(this);
}

enum GitLabMergeRequestState {
  closed,

  locked,

  merged,

  opened
}

class GitLabMilestone {
  final DateTime createdAt;

  final String description;

  final DateTime dueDate;

  final int id;

  final int iid;

  final int projectID;

  final DateTime startDate;

  final GitLabMilestoneState state;

  final String title;

  final DateTime updatedAt;

  final String webUrl;

  GitLabMilestone(
      {required this.createdAt,
      required this.description,
      required this.dueDate,
      required this.id,
      required this.iid,
      required this.projectID,
      required this.startDate,
      required this.state,
      required this.title,
      required this.updatedAt,
      required this.webUrl});

  factory GitLabMilestone.fromJson(Map<String, dynamic> json) =>
      _$GitLabMilestoneFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMilestoneToJson(this);
}

enum GitLabMilestoneState {
  active,

  closed
}

class GitLabPipeline {
  final int id;

  final String ref;

  final String sha;

  final GitLabPipelineStatus status;

  final String webUrl;

  GitLabPipeline(
      {required this.id,
      required this.ref,
      required this.sha,
      required this.status,
      required this.webUrl});

  factory GitLabPipeline.fromJson(Map<String, dynamic> json) =>
      _$GitLabPipelineFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabPipelineToJson(this);
}

enum GitLabPipelineStatus {
  cancelled,

  failed,

  pending,

  running,

  skipped,

  success
}

class GitLabUser {
  final String? avatarUrl;

  final int id;

  final String name;

  final GitLabUserState state;

  final String username;

  final String webUrl;

  GitLabUser(
      {this.avatarUrl,
      required this.id,
      required this.name,
      required this.state,
      required this.username,
      required this.webUrl});

  factory GitLabUser.fromJson(Map<String, dynamic> json) =>
      _$GitLabUserFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabUserToJson(this);
}

enum GitLabUserState {
  active,

  blocked,
}

==> danger_core-2.0.0.tar.gz: lib/src/models/gitlab_dsl.dart <==
import 'package:danger_core/src/mock_json_annotation.dart';

part 'gitlab_dsl.g.dart';

class GitLabDSL {
  final GitLabMergeRequest mergeRequest;

  final GitLabMetadata metadata;

  GitLabDSL({required this.mergeRequest, required this.metadata});

  factory GitLabDSL.fromJson(Map<String, dynamic> json) =>
      _$GitLabDSLFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabDSLToJson(this);
}

class GitLabDiffRefs {
  final String baseSha;

  final String headSha;

  final String startSha;

  GitLabDiffRefs(
      {required this.baseSha, required this.headSha, required this.startSha});

  factory GitLabDiffRefs.fromJson(Map<String, dynamic> json) =>
      _$GitLabDiffRefsFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabDiffRefsToJson(this);
}

class GitLabUserMergeData {
  final bool canMerge;

  GitLabUserMergeData({required this.canMerge});

  factory GitLabUserMergeData.fromJson(Map<String, dynamic> json) =>
      _$GitLabUserMergeDataFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabUserMergeDataToJson(this);
}

class GitLabMergeRequest {
  final bool? allowCollaboration;

  final bool? allowMaintainerToPush;

  final int? approvalsBeforeMerge;

  final GitLabUser? assignee;

  final GitLabUser author;

  final String changesCount;

  final DateTime? closedAt;

  final GitLabUser? closedBy;

  final String description;

  final GitLabDiffRefs diffRefs;

  final int downvotes;

  final DateTime? firstDeployedToProductionAt;

  final bool? forceRemoveSourceBranch;

  final int id;

  final int iid;

  final DateTime? latestBuildFinishedAt;

  final DateTime? latestBuildStartedAt;

  final List<String> labels;

  final String? mergeCommitSha;

  final DateTime? mergedAt;

  final GitLabUser? mergedBy;

  final bool mergeOnPipelineSuccess;

  final GitLabMilestone? milestone;

  final GitLabPipeline? pipeline;

  final int projectId;

  final String sha;

  final bool? shouldRemoveSourceBranch;

  final String sourceBranch;

  final int sourceProjectId;

  final GitLabMergeRequestState state;

  final bool subscribed;

  final String targetBranch;

  final int targetProjectId;

  final GitLabMergeRequestTimeStats? timeStats;

  final String title;

  final int upvotes;

  final GitLabUserMergeData userMergeData;

  final int userNotesCount;

  final String webUrl;

  final bool workInProgress;

  GitLabMergeRequest(
      {this.allowCollaboration,
      this.allowMaintainerToPush,
      this.approvalsBeforeMerge,
      this.assignee,
      required this.author,
      required this.changesCount,
      this.closedAt,
      this.closedBy,
      required this.description,
      required this.diffRefs,
      required this.downvotes,
      this.firstDeployedToProductionAt,
      this.forceRemoveSourceBranch,
      required this.id,
      required this.iid,
      this.latestBuildFinishedAt,
      this.latestBuildStartedAt,
      required this.labels,
      this.mergeCommitSha,
      this.mergedAt,
      this.mergedBy,
      required this.mergeOnPipelineSuccess,
      this.milestone,
      this.pipeline,
      required this.projectId,
      required this.sha,
      this.shouldRemoveSourceBranch,
      required this.sourceBranch,
      required this.sourceProjectId,
      required this.state,
      required this.subscribed,
      required this.targetBranch,
      required this.targetProjectId,
      required this.timeStats,
      required this.title,
      required this.upvotes,
      required this.userMergeData,
      required this.userNotesCount,
      required this.webUrl,
      required this.workInProgress});

  factory GitLabMergeRequest.fromJson(Map<String, dynamic> json) =>
      _$GitLabMergeRequestFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMergeRequestToJson(this);
}

class GitLabMergeRequestTimeStats {
  final int? humanTimeEstimate;

  final int? humanTimeSpent;

  final int timeEstimate;

  final int totalTimeSpent;

  GitLabMergeRequestTimeStats(
      {this.humanTimeEstimate,
      this.humanTimeSpent,
      required this.timeEstimate,
      required this.totalTimeSpent});

  factory GitLabMergeRequestTimeStats.fromJson(Map<String, dynamic> json) =>
      _$GitLabMergeRequestTimeStatsFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMergeRequestTimeStatsToJson(this);
}

class GitLabMetadata {
  final String pullRequestID;
  final String repoSlug;

  GitLabMetadata({required this.pullRequestID, required this.repoSlug});

  factory GitLabMetadata.fromJson(Map<String, dynamic> json) =>
      _$GitLabMetadataFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMetadataToJson(this);
}

enum GitLabMergeRequestState {
  closed,

  locked,

  merged,

  opened
}

class GitLabMilestone {
  final DateTime createdAt;

  final String description;

  final DateTime? dueDate;

  final int id;

  final int iid;

  final int projectID;

  final DateTime? startDate;

  final GitLabMilestoneState state;

  final String title;

  final DateTime updatedAt;

  final String webUrl;

  GitLabMilestone(
      {required this.createdAt,
      required this.description,
      this.dueDate,
      required this.id,
      required this.iid,
      required this.projectID,
      this.startDate,
      required this.state,
      required this.title,
      required this.updatedAt,
      required this.webUrl});

  factory GitLabMilestone.fromJson(Map<String, dynamic> json) =>
      _$GitLabMilestoneFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabMilestoneToJson(this);
}

enum GitLabMilestoneState {
  active,

  closed
}

class GitLabPipeline {
  final int id;

  final String ref;

  final String sha;

  final GitLabPipelineStatus status;

  final String webUrl;

  GitLabPipeline(
      {required this.id,
      required this.ref,
      required this.sha,
      required this.status,
      required this.webUrl});

  factory GitLabPipeline.fromJson(Map<String, dynamic> json) =>
      _$GitLabPipelineFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabPipelineToJson(this);
}

enum GitLabPipelineStatus {
  cancelled,

  failed,

  pending,

  running,

  skipped,

  success
}

class GitLabUser {
  final String? avatarUrl;

  final int id;

  final String name;

  final GitLabUserState state;

  final String username;

  final String webUrl;

  GitLabUser(
      {this.avatarUrl,
      required this.id,
      required this.name,
      required this.state,
      required this.username,
      required this.webUrl});

  factory GitLabUser.fromJson(Map<String, dynamic> json) =>
      _$GitLabUserFromJson(json);
  Map<String, dynamic> toJson() => _$GitLabUserToJson(this);
}

enum GitLabUserState {
  active,

  blocked,
}
